@@ -1,7 +1,7 @@
-# Ugly hack to get rid of spurious notes in package check, caused by uses
-# of dplyr::{rename, filter}. R is such a sad language.
+# Hack to get rid of spurious notes in package check, caused by uses
+# of dplyr::{rename, filter}.
 if (getRversion() >= "2.15.1")  utils::globalVariables(c(
-  "response", "Nreprocumul", "resp", "Mortality", "qinf95", "qsup95",
+  "id", "response", "Nreprocumul", "resp", "Mortality", "qinf95", "qsup95",
   "transf_conc", "obs", "pred", "..n..", "Points", "conc", "Line", "Nsurv",
   "time", "Conf.Int", "Cred.Lim", "Obs", "P50", "P2.5", "P97.5", "variable",
   "value", "jittered_conc", "reproRateInf", "reproRateSup", "curv_conc", "q50",
